@@ -32,10 +32,10 @@ typedef struct
 
   gboolean            read_only;
 
-  guint               color_changed_handler_id;
-  guint               name_changed_handler_id;
-  guint               readonly_changed_handler_id;
-  guint               visible_changed_handler_id;
+  gulong              color_changed_handler_id;
+  gulong              name_changed_handler_id;
+  gulong              readonly_changed_handler_id;
+  gulong              visible_changed_handler_id;
   gboolean            initialized;
 } GcalCalendarPrivate;
 
@@ -231,8 +231,9 @@ gcal_calendar_finalize (GObject *object)
   selectable_extension = e_source_get_extension (priv->source, E_SOURCE_EXTENSION_CALENDAR);
 
   gcal_clear_signal_handler (&priv->color_changed_handler_id, selectable_extension);
-  gcal_clear_signal_handler (&priv->name_changed_handler_id, selectable_extension);
+  gcal_clear_signal_handler (&priv->name_changed_handler_id, priv->source);
   gcal_clear_signal_handler (&priv->readonly_changed_handler_id, priv->client);
+  gcal_clear_signal_handler (&priv->visible_changed_handler_id, selectable_extension);
 
   g_clear_object (&priv->client);
   g_clear_object (&priv->source);
