@@ -18,6 +18,8 @@
 
 #define G_LOG_DOMAIN "GcalManager"
 
+#include "gcal-application.h"
+#include "gcal-context.h"
 #include "gcal-debug.h"
 #include "gcal-manager.h"
 #include "gcal-utils.h"
@@ -88,6 +90,8 @@ struct _GcalManager
   GCancellable       *async_ops;
 
   gint                clients_synchronizing;
+
+  GcalContext        *context;
 };
 
 G_DEFINE_TYPE (GcalManager, gcal_manager, G_TYPE_OBJECT)
@@ -95,6 +99,7 @@ G_DEFINE_TYPE (GcalManager, gcal_manager, G_TYPE_OBJECT)
 enum
 {
   PROP_0,
+  PROP_CONTEXT,
   PROP_DEFAULT_CALENDAR,
   PROP_SYNCHRONIZING,
   NUM_PROPS
@@ -641,6 +646,12 @@ gcal_manager_finalize (GObject *object)
   g_clear_object (&self->e_data_model);
   g_clear_object (&self->shell_search_data_model);
 
+  if (self->context)
+    {
+      g_object_remove_weak_pointer (G_OBJECT (self->context), (gpointer *)&self->context);
+      self->context = NULL;
+    }
+
   if (self->search_view_data)
     {
       g_clear_pointer (&self->search_view_data->query, g_free);
@@ -664,6 +675,12 @@ gcal_manager_set_property (GObject      *object,
 
   switch (property_id)
     {
+    case PROP_CONTEXT:
+      g_assert (self->context == NULL);
+      self->context = g_value_get_object (value);
+      g_object_add_weak_pointer (G_OBJECT (self->context), (gpointer *)&self->context);
+      break;
+
     case PROP_DEFAULT_CALENDAR:
       gcal_manager_set_default_calendar (self, g_value_get_object (value));
       break;
@@ -691,6 +708,10 @@ gcal_manager_get_property (GObject    *object,
 
   switch (property_id)
     {
+    case PROP_CONTEXT:
+      g_value_set_object (value, self->context);
+      break;
+
     case PROP_DEFAULT_CALENDAR:
       g_value_set_object (value, gcal_manager_get_default_calendar (self));
       break;
@@ -715,6 +736,17 @@ gcal_manager_class_init (GcalManagerClass *klass)
   object_class->set_property = gcal_manager_set_property;
   object_class->get_property = gcal_manager_get_property;
 
+  /**
+   * GcalManager:context:
+   *
+   * The #GcalContext.
+   */
+  properties[PROP_CONTEXT] = g_param_spec_object ("context",
+                                                  "Data context",
+                                                  "Data context",
+                                                  GCAL_TYPE_CONTEXT,
+                                                  G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS);
+
   /**
    * GcalManager:default-calendar:
    *
@@ -781,15 +813,18 @@ gcal_manager_init (GcalManager *self)
 /* Public API */
 /**
  * gcal_manager_new:
+ * @context: a #GcalContext
  *
  * Creates a new #GcalManager.
  *
  * Returns: (transfer full): a newly created #GcalManager
  */
 GcalManager*
-gcal_manager_new (void)
+gcal_manager_new (GcalContext *context)
 {
-  return g_object_new (GCAL_TYPE_MANAGER, NULL);
+  return g_object_new (GCAL_TYPE_MANAGER,
+                       "context", context,
+                       NULL);
 }
 
 /**
@@ -877,19 +912,24 @@ void
 gcal_manager_setup_shell_search (GcalManager             *self,
                                  ECalDataModelSubscriber *subscriber)
 {
+  GTimeZone *zone;
+
   g_return_if_fail (GCAL_IS_MANAGER (self));
 
   if (self->shell_search_data_model)
     return;
 
   self->shell_search_data_model = e_cal_data_model_new (gcal_thread_submit_job);
-  g_signal_connect_swapped (self->shell_search_data_model,
-                            "view-state-changed",
-                            G_CALLBACK (model_state_changed),
-                            self);
+  g_signal_connect_object (self->shell_search_data_model,
+                           "view-state-changed",
+                           G_CALLBACK (model_state_changed),
+                           self,
+                           G_CONNECT_SWAPPED);
 
   e_cal_data_model_set_expand_recurrences (self->shell_search_data_model, TRUE);
-  e_cal_data_model_set_timezone (self->shell_search_data_model, e_cal_util_get_system_timezone ());
+
+  zone = gcal_context_get_timezone (self->context);
+  e_cal_data_model_set_timezone (self->shell_search_data_model, gcal_timezone_to_icaltimezone (zone));
 
   self->search_view_data = g_new0 (ViewStateData, 1);
   self->search_view_data->subscriber = subscriber;
@@ -1420,6 +1460,8 @@ gcal_manager_get_events (GcalManager *self,
                          ICalTime    *end_date)
 {
   time_t range_start, range_end;
+  GTimeZone *zone;
+  ICalTimezone *tz;
   GatherEventData data = {
     .manager = self,
     .events = NULL,
@@ -1429,8 +1471,10 @@ gcal_manager_get_events (GcalManager *self,
 
   g_return_val_if_fail (GCAL_IS_MANAGER (self), NULL);
 
-  range_start = i_cal_time_as_timet_with_zone (start_date, e_cal_util_get_system_timezone ());
-  range_end = i_cal_time_as_timet_with_zone (end_date, e_cal_util_get_system_timezone ());
+  zone = gcal_context_get_timezone (self->context);
+  tz = gcal_timezone_to_icaltimezone (zone);
+  range_start = i_cal_time_as_timet_with_zone (start_date, tz);
+  range_end = i_cal_time_as_timet_with_zone (end_date, tz);
 
   e_cal_data_model_foreach_component (self->e_data_model,
                                       range_start,
@@ -1520,6 +1564,7 @@ gcal_manager_startup (GcalManager *self)
   GList *sources, *l;
   GError *error = NULL;
   ESourceCredentialsProvider *credentials_provider;
+  GTimeZone *zone;
 
   GCAL_ENTRY;
 
@@ -1608,19 +1653,21 @@ gcal_manager_startup (GcalManager *self)
 
   /* The eds_credentials_prompter responses to REQUIRED and REJECTED reasons,
      the SSL_FAILED should be handled elsewhere. */
-  g_signal_connect (self->source_registry, "credentials-required", G_CALLBACK (source_credentials_required_cb), self);
+  g_signal_connect_object (self->source_registry, "credentials-required", G_CALLBACK (source_credentials_required_cb), self, 0);
 
   e_credentials_prompter_process_awaiting_credentials (self->credentials_prompter);
 
-  g_signal_connect_swapped (self->source_registry, "source-added", G_CALLBACK (load_source), self);
-  g_signal_connect_swapped (self->source_registry, "source-removed", G_CALLBACK (remove_source), self);
-  g_signal_connect_swapped (self->source_registry, "source-changed", G_CALLBACK (source_changed), self);
+  g_signal_connect_object (self->source_registry, "source-added", G_CALLBACK (load_source), self, G_CONNECT_SWAPPED);
+  g_signal_connect_object (self->source_registry, "source-removed", G_CALLBACK (remove_source), self, G_CONNECT_SWAPPED);
+  g_signal_connect_object (self->source_registry, "source-changed", G_CALLBACK (source_changed), self, G_CONNECT_SWAPPED);
 
   /* create data model */
   self->e_data_model = e_cal_data_model_new (gcal_thread_submit_job);
 
   e_cal_data_model_set_expand_recurrences (self->e_data_model, TRUE);
-  e_cal_data_model_set_timezone (self->e_data_model, e_cal_util_get_system_timezone ());
+
+  zone = gcal_context_get_timezone (self->context);
+  e_cal_data_model_set_timezone (self->e_data_model, gcal_timezone_to_icaltimezone (zone));
 
   sources = e_source_registry_list_enabled (self->source_registry, E_SOURCE_EXTENSION_CALENDAR);
 
