@@ -492,7 +492,7 @@ update_sidebar (GcalYearView *year_view)
         {
           child_widget = l->data;
           gtk_widget_show (child_widget);
-          g_signal_connect (child_widget, "activate", G_CALLBACK (event_activated), year_view);
+          g_signal_connect_object (child_widget, "activate", G_CALLBACK (event_activated), year_view, 0);
           g_object_set_data (G_OBJECT (child_widget), "shift", GINT_TO_POINTER (i));
           gtk_container_add (GTK_CONTAINER (year_view->events_sidebar), child_widget);
         }
@@ -1515,16 +1515,14 @@ navigator_drag_drop_cb (GcalYearView   *self,
           GcalEvent *event;
           GDateTime *start_dt, *end_dt;
           GDateTime *drop_date;
-          ESource *source;
 
           event_widget = GCAL_EVENT_WIDGET (gtk_drag_get_source_widget (context));
           event = gcal_event_widget_get_event (event_widget);
           calendar = gcal_event_get_calendar (event);
-          source = gcal_calendar_get_source (calendar);
           mod = GCAL_RECURRENCE_MOD_THIS_ONLY;
 
           if (gcal_event_has_recurrence (event) &&
-              !ask_recurrence_modification_type (GTK_WIDGET (self), &mod, source))
+              !ask_recurrence_modification_type (GTK_WIDGET (self), &mod, calendar))
             {
               goto out;
             }
@@ -1746,6 +1744,7 @@ gcal_year_view_set_property (GObject      *object,
       break;
 
     case PROP_CONTEXT:
+      g_assert (self->context == NULL);
       self->context = g_value_dup_object (value);
 
       g_signal_connect_object (gcal_context_get_clock (self->context),
@@ -1760,8 +1759,6 @@ gcal_year_view_set_property (GObject      *object,
                                self,
                                0);
       update_weather (self);
-
-      g_object_notify (object, "context");
       break;
 
     case PROP_SHOW_WEEK_NUMBERS:
@@ -2118,7 +2115,7 @@ gcal_year_view_init (GcalYearView *self)
   /* bind GNOME Shell' show week numbers property to GNOME Calendar's one */
   self->calendar_settings = g_settings_new ("org.gnome.desktop.calendar");
   g_settings_bind (self->calendar_settings, "show-weekdate", self, "show-week-numbers", G_SETTINGS_BIND_DEFAULT);
-  g_signal_connect_swapped (self->calendar_settings, "changed::show-weekdate", G_CALLBACK (gtk_widget_queue_draw), self);
+  g_signal_connect_object (self->calendar_settings, "changed::show-weekdate", G_CALLBACK (gtk_widget_queue_draw), self, G_CONNECT_SWAPPED);
 
   /* layout */
   self->number_of_columns = 4;
